﻿const { getAssemblyExports } = await globalThis.getDotnetRuntime(0);
var nameSpace = (await getAssemblyExports("SimpleWebChat.BlazorWasm.dll")).SimpleWebChat.BlazorWasm.Modules;
var DotNetInterop = nameSpace.AudioCaptureModule;

var isRunning = false;
var stream;
var recorder;

export async function init() {
    if (navigator.mediaDevices && navigator.mediaDevices.getUserMedia)
        stream = await navigator.mediaDevices.getUserMedia({ audio: true });
    else throw "failure to getUserMedia";

    if (stream) {

        var mime;
        if (MediaRecorder.isTypeSupported('audio/webm;codecs=OPUS')) {
            mime = 'audio/webm;codecs=OPUS';
        } else if (MediaRecorder.isTypeSupported("audio/mp4;codecs=mp4a.40.2")) {
            mime = "audio/mp4;codecs=mp4a.40.2";
        } else throw "No support audio recording codec in OPUS or MP4A";

        recorder = new MediaRecorder(stream, {
            audioBitsPerSecond: 64000,
            mimeType: mime
        });

        recorder.ondataavailable = async (r) => {
            DotNetInterop.JsFeedChunk(new Uint8Array(await r.data.arrayBuffer()));
        };

        recorder.onstop = () => {
            if (isRunning) {
                recorder.start();
                setTimeout(() => {
                    if (isRunning) recorder.stop();
                }, 1000);
            }
        };
    }
    return !!stream;
}

export async function start() {
    isRunning = true;
    if (recorder.state != 'recording') {
        recorder.start();
        setTimeout(() => {
            if (isRunning) recorder.stop();
        }, 1000);
    }
}

export async function stop() {
    isRunning = false;
    recorder.stop();
}

